/* global visualizer1 */
/* global Handsontable */
(function($, v) {

    var __dataMightHaveChanged  = false;

    $.fn.loadDataInTable    = function(cols, d, hot){
        var data        = [];
        var heading     = [];
        var type        = [];
        var i;
        for( i = 0; i < cols.length; i++){
            heading[heading.length] = cols[i].label;
            type[type.length]       = cols[i].type;
        }

        data[data.length]   = heading;
        data[data.length]   = type;
        
        for( i = 0; i < d.length; i++){
            data[data.length]   = d[i];
        }

        hot.loadData(data);

    };

    $.fn.submitData         = function(hot){
        if(__dataMightHaveChanged){
            $( '#editor-chart-button' ).attr("disabled", "disabled");

            __dataMightHaveChanged  = false;
            $('#chart-data').val(JSON.stringify(hot.getData()));
            $('#canvas').lock();
            if($('#csv-form').length > 0){
                $('#csv-form').submit();
            }else{
                $('#editor-form').submit();
            }
            $( '#editor-chart-button' ).removeAttr("disabled");
        }
    };

    v.render                = function(series, data){
        $.fn.loadDataInTable(series, data, hot);
        $( '#editor-chart-button' ).removeAttr("disabled");
    };

    var container   = $( '#chart-editor' ).get(0);
    var hot         = new Handsontable(
        container,
        {
            language: v.locale,
            startRows: 10,
            startCols: 10,
            minRows: 35,
            minSpareRows: 35,
            minCols: 35,
            rowHeaders: true,
            colHeaders: true,
            allowInvalid: false,
            cells: function (row, col, prop) {
                var cellProperties;
                if (row === 1) {
                    cellProperties = {
                        type: 'autocomplete',
                        source: v.types,
                        strict: true
                    };
                    return cellProperties;
                }
            },
            afterLoad: function (){
                $( '#editor-chart-button' ).removeAttr("disabled");
                $.fn.submitData(this);
            }
        }
    );

    if(v.data){
        $.fn.loadDataInTable(v.data.series, v.data.data, hot);
    }


    $( '#existing-chart' ).on( 'click', function(){
        $.ajax({
            url: $( '#editor-resources' ).length > 0 ? $( '#editor-resources' ).attr( 'data-ajax' ) : $(this).attr( 'data-viz-link' ),
            data: 'chart_id=' + $( '#chart-id' ).val(),
            success: function(d, textStatus, XMLHttpRequest){
                if( d.success ){
                    __dataMightHaveChanged  = true;
                    $.fn.loadDataInTable(d.series, d.data, hot);
                    $.fn.submitData(hot);
                }
            }
        });
    });

    $( '.visualizer-src-tab' ).on( 'click', function(){
        if($('.visualizer-editor-tab').attr('data-current') === 'editor') {
            $('.visualizer-editor-tab').attr( 'data-current', 'chart' );
            $( '#chart-editor' ).hide();
            $( '#canvas' ).css("z-index", "1");
        }
    } );

    $( '#editor-chart-button' ).on( 'click', function(){
        if( $(this).attr( 'data-current' ) === 'chart'){
            $(this).val( $(this).attr( 'data-t-editor' ) );
            $(this).html( $(this).attr( 'data-t-editor' ) );
            $(this).attr( 'data-current', 'editor' );
            $( '.visualizer-editor-lhs' ).hide();
            $( '#chart-editor' ).css("z-index", "9999").show();
            $( '#canvas' ).css("z-index", "-100");
        }else{
            __dataMightHaveChanged  = true;
            $.fn.submitData(hot);
            $(this).val( $(this).attr( 'data-t-chart' ) );
            $(this).html( $(this).attr( 'data-t-chart' ) );
            $(this).attr( 'data-current', 'chart' );
            $( '#chart-editor' ).hide();
            $( '#canvas' ).css("z-index", "1");
        }
    } );

    $( '#filter-chart-button' ).on( 'click', function(){
        if( $(this).attr( 'data-current' ) === 'chart'){
            $(this).val( $(this).attr( 'data-t-filter' ) );
            $(this).html( $(this).attr( 'data-t-filter' ) );
            $(this).attr( 'data-current', 'filter' );
            $( '.visualizer-editor-lhs' ).hide();
            $( '#filter-wizard' ).css("z-index", "9999").show();
            $( '#canvas' ).hide();
        }else{
            if($('table.filter-wizard tr').length === 2){
                window.alert(v.l10n['filter_config_error']);
                return;
            }
            var filter_button = $(this);
            $.ajax({
                url     : v.ajax['url'],
                method  : 'post',
                data    : {
                    'action'    : v.ajax['actions']['filter_get_data'],
                    'nonce'     : v.ajax['nonces']['filter_get_data'],
                    'props'     : $('#filter-wizard-form').serialize(),
                    'chart_id'  : $('#visualizer-chart-id').attr('data-id')
                },
                success : function(d, textStatus, XMLHttpRequest){
                    if(d.success) {
                        $('#canvas').lock();
                        $('#chart-data').val(d.data);
                        $('#chart-data-src').val(v.filter);
                        if($('#csv-form').length > 0){
                            $('#csv-form').submit();
                        }else{
                            $('#editor-form').submit();
                        }
                        filter_button.val( filter_button.attr( 'data-t-chart' ) );
                        filter_button.html( filter_button.attr( 'data-t-chart' ) );
                        filter_button.attr( 'data-current', 'chart' );
                        $( '#filter-wizard' ).hide();
                        $( '#canvas' ).css("z-index", "1").show();
                    }
                }
            });
        }
    } );

    $( '#visualizer-post-types' ).on( 'change', function(){
        var post_type   = $(this).val();
        $('#visualizer-post-fields').empty().append('<option value="">' + v.l10n['loading'] + '</option>').removeAttr('multiple').trigger('chosen:updated');
        $('tr.filter-wizard-new').remove();
        $('#filter-wizard-post-type').val(post_type);

        $.ajax({
            url     : v.ajax['url'],
            method  : 'post',
            data    : {
                'action'    : v.ajax['actions']['filter_get_props'],
                'nonce'     : v.ajax['nonces']['filter_get_props'],
                'post_type' : post_type
            },
            success : function(d, textStatus, XMLHttpRequest){
                if(d.success) {
                    $('#visualizer-post-fields').empty().attr('multiple', 'multiple');
                    $.each(d.fields, function(i, x){
                        $('#visualizer-post-fields').append('<option value="' + x + '">' + x + '</option>');
                    });
                    $('#visualizer-post-fields').trigger('chosen:updated');
                }
            }
        });
    });

    function update_filter_table(params){
        if(params.selected) {
            var tr = $('.filter-wizard-template').clone().addClass('vz-filter-row').removeClass('filter-wizard-template').addClass('filter-wizard-new').removeAttr('style').attr('id', params.selected.replace('(', '_').replace(')', '_'));
            $('table.filter-wizard').append(tr);
            tr.find('td').first().html(params.selected);
            tr.find('input').val(params.selected);
        }else{
            $('tr#' + params.deselected.replace('(', '_').replace(')', '_')).remove();
        }
    }

    $( '#settings-button' ).on( 'click', function(){
        if( $('#editor-chart-button').attr( 'data-current' ) !== 'chart' ){
            __dataMightHaveChanged  = true;
            $.fn.submitData(hot);
        }
    });

    $('body').on('click', '#vz-save-schedule', function(){

        var url = $('#vz-schedule-url').val();

        if (url !== '') {
            if (/^([a-z]([a-z]|\d|\+|-|\.)*):(\/\/(((([a-z]|\d|-|\.|_|~|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])|(%[\da-f]{2})|[!\$&'\(\)\*\+,;=]|:)*@)?((\[(|(v[\da-f]{1,}\.(([a-z]|\d|-|\.|_|~)|[!\$&'\(\)\*\+,;=]|:)+))\])|((\d|[1-9]\d|1\d\d|2[0-4]\d|25[0-5])\.(\d|[1-9]\d|1\d\d|2[0-4]\d|25[0-5])\.(\d|[1-9]\d|1\d\d|2[0-4]\d|25[0-5])\.(\d|[1-9]\d|1\d\d|2[0-4]\d|25[0-5]))|(([a-z]|\d|-|\.|_|~|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])|(%[\da-f]{2})|[!\$&'\(\)\*\+,;=])*)(:\d*)?)(\/(([a-z]|\d|-|\.|_|~|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])|(%[\da-f]{2})|[!\$&'\(\)\*\+,;=]|:|@)*)*|(\/((([a-z]|\d|-|\.|_|~|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])|(%[\da-f]{2})|[!\$&'\(\)\*\+,;=]|:|@)+(\/(([a-z]|\d|-|\.|_|~|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])|(%[\da-f]{2})|[!\$&'\(\)\*\+,;=]|:|@)*)*)?)|((([a-z]|\d|-|\.|_|~|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])|(%[\da-f]{2})|[!\$&'\(\)\*\+,;=]|:|@)+(\/(([a-z]|\d|-|\.|_|~|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])|(%[\da-f]{2})|[!\$&'\(\)\*\+,;=]|:|@)*)*)|((([a-z]|\d|-|\.|_|~|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])|(%[\da-f]{2})|[!\$&'\(\)\*\+,;=]|:|@)){0})(\?((([a-z]|\d|-|\.|_|~|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])|(%[\da-f]{2})|[!\$&'\(\)\*\+,;=]|:|@)|[\uE000-\uF8FF]|\/|\?)*)?(\#((([a-z]|\d|-|\.|_|~|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])|(%[\da-f]{2})|[!\$&'\(\)\*\+,;=]|:|@)|\/|\?)*)?$/i.test(url)) {
                if (url.substr(url.length - 8) === '/pubhtml') {
                    url = url.substring(0, url.length - 8) + '/export?format=csv';
                }
                $('#canvas').lock();
                $(this).parent().submit();
            } else {
                window.alert(v.l10n.invalid_source);
            }
        }
    });
    function refresh_table(){
        if( $( "#filter-wizard-details tr.vz-filter-row" ).size() > 0 ) {
            $("#filter-wizard-details").show();
            $("#vz-no-fields").hide();
        }
        else {
            $("#filter-wizard-details").hide();
            $("#vz-no-fields").show();
        }
    }
    $(document).ready(function(){ 
        if($('.visualizer-remote-url') && $('.visualizer-remote-url').val().length > 0){ 
            $('.visualizer-import-url').addClass('open');
            $('.visualizer-import-url-schedule').addClass('open');
            $('.visualizer-import-url-schedule').parent().find('.viz-section-items').show();
        }

        refresh_table();

        $('.visualizer-chosen').chosen({
            width               : '50%',
            max_selected_options: v.max_selected_options,
            search_contains     : true
        });
        $('#visualizer-post-fields').on('change', function(evt, params) {
            update_filter_table(params);
            refresh_table();
        });
    });

})(jQuery, visualizer1);